<!--- SPDX-License-Identifier: Apache-2.0 -->

# SIGs - Special Interest Groups

As described in the ONNX [governance](/community/readme.md#sig---special-interest-groups), Special Interest Groups (SIGs) are persistent groups responsible for specific parts of the project. SIGs have open and transparent proceedings to develop goals and implement code contributions. SIGs are also responsible for ongoing maintenance of the code in their areas.

## Joining a SIG

If you are interested in participating, please [join the discussion](https://slack.lfai.foundation/) in the respective Slack channels. Details about any upcoming meetings will also be shared in the Slack channels. SIG artifacts can be found in the [sigs repository](https://github.com/onnx/sigs).

You can find the schedule of SIG meetings on the [LF AI calendar](https://wiki.lfai.foundation/pages/viewpage.action?pageId=18481196)

## Current SIGs

| Name | Responsibilities |
| ---- | ---------------- |
| [Architecture & Infra](https://lfaifoundation.slack.com/archives/C018Y2QG7V2) | Defining and maintaining the core ONNX format, the build and CI/CD systems for ONNX repositories, publishing release packages for ONNX, the onnx-docker repository, and creating tools to help integrate with and test against the ONNX standard. This SIG is also the defacto owner of files in the main ONNX repository unless explicitly owned by another SIG. |
| [Operators](https://lfaifoundation.slack.com/archives/C018Y2RAY4C) | Determining the operators that are part of the ONNX spec (ONNX and ONNX-ML domains), ensuring high quality operator definitions and documentation, establishing criteria for adding new operators, managing ops domains and compliance tiers, and enforcing versioning mechanisms. |
| [Converters](https://lfaifoundation.slack.com/archives/C0171FSKZBN) | Developing and maintaining the various converter repositories under ONNX. |
| [Models and tutorials](https://lfaifoundation.slack.com/archives/C018RE2BRBL) | Providing a comprehensive collection of state of the art ONNX models from a variety of sources and making it easy for users to get started with ONNX and the ecosystem around it. |
